==> GrufSpaces-0.5.0.tar.gz: GrufSpaces/tests/testPloneCollabSpaceInterface.py <==
# $Id: testPloneCollabSpaceInterface.py,v 1.1 2004/05/14 08:51:03 roeder Exp $

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# use recent version (0.6+) of PloneTestCase from CVS:
from Products.PloneTestCase import PloneTestCase

from Products.GrufSpaces.GroupSpace import GroupSpace

#PloneTestCase.installProduct('PortalTransforms')
#PloneTestCase.installProduct('Archetypes')
PloneTestCase.installProduct('GrufSpaces')
PloneTestCase.setupPloneSite()

from AccessControl import getSecurityManager

class TestPloneCollabSpaceRolesReg(PloneTestCase.PloneTestCase):
    "Test methods of the CollabSpace class - roles registration."

    def afterSetUp(self):
        self.loginAsPortalOwner()
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.securityManager = getSecurityManager()

    def login(self, userid=None):
        if userid:
            PloneTestCase.PloneTestCase.login(self, userid)
            pm = getToolByName(self.portal, 'portal_membership')
            self.portal.REQUEST.set('_portaluser', pm.getMemberById(userid))
        else:
            PloneTestCase.PloneTestCase.login(self)

# here comes the test

    def testBasicInfo(self):
        self.assertEquals('pcs', self.pcs.getId())
        self.assertEquals('GroupSpace', self.pcs.Type())
        self.assertEquals('GroupSpace', self.pcs.meta_type)
        self.assertEquals('GroupSpace', self.pcs.getTypeInfo().Metatype())
        self.pcs.edit(title='PCS', description='My Plone Collab Space')
        self.assertEquals('PCS', self.pcs.Title())
        self.assertEquals('My Plone Collab Space', self.pcs.Description())
        pt = self.portal.portal_types
        fti = pt.getTypeInfo('GroupSpace')

class TestPloneCollabSpaceUserAssignment(PloneTestCase.PloneTestCase):
    "Test methods of the CollabSpace class - user assignment."

    def afterSetUp(self):
        self.loginAsPortalOwner()
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.user1 = self.createMember('user1', 'abcd1', 'abc1@domain.tld')
        self.user2 = self.createMember('user2', 'abcd2', 'abc2@domain.tld')
        self.user3 = self.createMember('user3', 'abcd3', 'abc3@domain.tld')
        self.user4 = self.createMember('user4', 'abcd4', 'abc4@domain.tld')

# here comes the test:

    # still missing:
    # - check catalog updates on local role changes

    def testAssignToCollabRole(self):
        self.pcs.assignToCollabRole('GroupMember', 'user1')
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'user1 has not got the local role "GroupMember" - roles: %s' % `roles`)

    def testAssignToCollabRoleUserNotExists(self):
        self.assertRaises(ValueError, self.pcs.assignToCollabRole, 'Participant', 'nobody')

    def testAssignToCollabRoleNotRegistered(self):
        self.assertRaises(ValueError, self.pcs.assignToCollabRole, 'Reviewer', 'user1')

    def testGetCollabUsers(self):
        self.pcs.assignToCollabRole('GroupMember', 'user1')
        users = self.pcs.getCollabUsers()
        self.assertEquals(('user1',), users)

    def testGetCollabUsersWithSelection(self):
        self.pcs.assignToCollabRole('GroupMember', 'user1')
        self.pcs.assignToCollabRole('GroupAdmin', 'user2')
        self.pcs.assignToCollabRole('GroupVisitor', 'user3')
        self.pcs.assignToCollabRole('GroupLeader', 'user4')
        users = self.pcs.getCollabUsers('GroupMember')
        self.assertEquals(('user1',), users)
        users = self.pcs.getCollabUsers('GroupAdmin')
        self.assertEquals(('user2',), users)
        users = self.pcs.getCollabUsers('GroupVisitor')
        self.assertEquals(('user3',), users)
        users = self.pcs.getCollabUsers('GroupLeader')
        self.assertEquals(('user4',), users)


    def testGetCollabUserObjects(self):
        self.pcs.assignToCollabRole('GroupMember', 'user1')
        users = self.pcs.getCollabUserObjects()
        self.assertEquals(['user1'], [ u.getUserName() for u in users ])

    def testGetCollabUserDictionary(self):
        self.pcs.assignToCollabRole('GroupMember', 'user1')
        userdict = self.pcs.getCollabUserDictionary()
        self.assertEquals({'GroupMember': ('user1',)}, userdict)

    def testGroupAssignToCollabRole(self):
        pm = self.portal.portal_membership
        self.group1 = self.createGroup('group1')
        self.group1.addMember('user1')
        self.portal.manage_permission('Add portal content', ('Participant',), 1)
        self.pcs.assignToCollabRole('GroupMember', self.group1.getUserName())
        roles = self.group1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'group1 has not got the local role "GroupMember" - roles: %s' % `roles`)
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'group1 has not got the "Add portal content" permission')
        self.login('user1')
        self.pcs.invokeFactory('Document', 'td1')
        self.assertEquals(['td1'], self.pcs.contentIds())
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')

    def testGetCollabUserObjectsGroup(self):
        self.group1 = self.createGroup('group1')
        self.pcs.assignToCollabRole('GroupMember', self.group1.getUserName())
        users = self.pcs.getCollabUserObjects()
        self.assertEquals([self.group1.getUserName()], [ u.getUserName() for u in users ])
        self.assertEquals(['group1'], [ u.getGroupName() for u in users ])
        self.failUnless(hasattr(users[0], 'getGroupMembers'))

# utility methods:

    def createMember(self, id, pw, email, roles=('Member',)):
        pr = self.portal.portal_registration
        member = pr.addMember(id, pw, roles, properties={ 'username': id, 'email' : email })
        return member

    def createGroup(self, id):
        pg = self.portal.portal_groups
        pg.addGroup(id, '', (), ())
        return pg.getGroupById(id)


if __name__ == '__main__':
    framework()
else:
    # While framework.py provides its own test_suite()
    # method the testrunner utility does not.
    from unittest import TestSuite, makeSuite
    def test_suite():
        suite = TestSuite()
        suite.addTest(makeSuite(TestPloneCollabSpaceRolesReg))
        suite.addTest(makeSuite(TestPloneCollabSpaceUserAssignment))
        return suite

==> GrufSpaces-0.6.tar.gz: GrufSpaces/tests/testPloneCollabSpaceInterface.py <==
# $Id: testPloneCollabSpaceInterface.py,v 1.3 2005/11/06 23:03:58 roeder Exp $

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

# use recent version (0.6+) of PloneTestCase from CVS:
from Products.PloneTestCase import PloneTestCase

from Products.GrufSpaces.GroupSpace import GroupSpace

#PloneTestCase.installProduct('PortalTransforms')
#PloneTestCase.installProduct('Archetypes')
PloneTestCase.installProduct('GrufSpaces')
PloneTestCase.setupPloneSite()

from AccessControl import getSecurityManager

class TestPloneCollabSpaceRolesReg(PloneTestCase.PloneTestCase):
    "Test methods of the CollabSpace class - roles registration."

    def afterSetUp(self):
        self.loginAsPortalOwner()
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.securityManager = getSecurityManager()

    def login(self, userid=None):
        if userid:
            PloneTestCase.PloneTestCase.login(self, userid)
            pm = getToolByName(self.portal, 'portal_membership')
            self.portal.REQUEST.set('_portaluser', pm.getMemberById(userid))
        else:
            PloneTestCase.PloneTestCase.login(self)

# here comes the test

    def testBasicInfo(self):
        self.assertEquals('pcs', self.pcs.getId())
        self.assertEquals('GroupSpace', self.pcs.Type())
        self.assertEquals('GroupSpace', self.pcs.meta_type)
        self.assertEquals('GroupSpace', self.pcs.getTypeInfo().Metatype())
        self.pcs.edit(title='PCS', description='My Plone Collab Space')
        self.assertEquals('PCS', self.pcs.Title())
        self.assertEquals('My Plone Collab Space', self.pcs.Description())
        pt = self.portal.portal_types
        fti = pt.getTypeInfo('GroupSpace')

class TestPloneCollabSpaceUserAssignment(PloneTestCase.PloneTestCase):
    "Test methods of the CollabSpace class - user assignment."

    def afterSetUp(self):
        self.loginAsPortalOwner()
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.user1 = self.createMember('user1', 'abcd1', 'abc1@domain.tld')
        self.user2 = self.createMember('user2', 'abcd2', 'abc2@domain.tld')
        self.user3 = self.createMember('user3', 'abcd3', 'abc3@domain.tld')
        self.user4 = self.createMember('user4', 'abcd4', 'abc4@domain.tld')

# here comes the test:

    # still missing:
    # - check catalog updates on local role changes

    def testassignCollabRoleToUser(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'user1 has not got the local role "GroupMember" - roles: %s' % `roles`)

    def testassignCollabRoleToUserUserNotExists(self):
        self.assertRaises(ValueError, self.pcs.assignCollabRoleToUser, 'Participant', 'nobody')

    def testassignCollabRoleToUserNotRegistered(self):
        self.assertRaises(ValueError, self.pcs.assignCollabRoleToUser, 'Reviewer', 'user1')

    def testGetCollabUsers(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        users = self.pcs.getCollabUsers()
        self.assertEquals(('user1',), users)

    def testGetCollabUsersWithSelection(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        self.pcs.assignCollabRoleToUser('GroupAdmin', 'user2')
        self.pcs.assignCollabRoleToUser('GroupVisitor', 'user3')
        self.pcs.assignCollabRoleToUser('GroupLeader', 'user4')
        users = self.pcs.getCollabUsers('GroupMember')
        self.assertEquals(('user1',), users)
        users = self.pcs.getCollabUsers('GroupAdmin')
        self.assertEquals(('user2',), users)
        users = self.pcs.getCollabUsers('GroupVisitor')
        self.assertEquals(('user3',), users)
        users = self.pcs.getCollabUsers('GroupLeader')
        self.assertEquals(('user4',), users)


    def testGetCollabUserObjects(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        users = self.pcs.getCollabUserObjects()
        self.assertEquals(['user1'], [ u.getUserName() for u in users ])

    def testGetCollabUserDictionary(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        userdict = self.pcs.getCollabUserDictionary()
        self.assertEquals({'GroupMember': ('user1',)}, userdict)

    def testassignCollabRoleToGroup(self):
        pm = self.portal.portal_membership
        self.group1 = self.createGroup('group1')
        self.group1.addMember('user1')
        self.portal.manage_permission('Add portal content', ('Participant',), 1)
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'user1 has not got the local role "GroupMember" - roles: %s' % `roles`)
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')
        self.login('user1')
        self.pcs.invokeFactory('Document', 'td1')
        self.assertEquals(['td1'], self.pcs.contentIds())
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')

    def testRemoveCollabRoleFromGroup(self):
        pm = self.portal.portal_membership
        self.group1 = self.createGroup('group1')
        self.group1.addMember('user1')
        self.portal.manage_permission('Add portal content', ('Participant',), 1)
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        self.pcs.removeCollabRoleFromGroup('GroupMember', self.group1.getUserName())
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless(not 'GroupMember' in roles,
            'user1 has got the local role "GroupMember" - roles: %s' % `roles`)
        self.login('user1')
        error=""
        try:
            self.pcs.invokeFactory('Document', 'td1')
        except:
            error="Unauthorized"
        self.assertEquals(error, "Unauthorized")
        self.assertEquals([], self.pcs.contentIds())
        self.failIf(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')

    def testGetCollabUserObjectsGroup(self):
        self.group1 = self.createGroup('group1')
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        users = self.pcs.getCollabUserObjects()
        self.assertEquals([self.group1.getUserName()], [ u.getUserName() for u in users ])
        self.assertEquals(['group1'], [ u.getGroupName() for u in users ])
        self.failUnless(hasattr(users[0], 'getGroupMembers'))

# utility methods:

    def createMember(self, id, pw, email, roles=('Member',)):
        pr = self.portal.portal_registration
        member = pr.addMember(id, pw, roles, properties={ 'username': id, 'email' : email })
        return member

    def createGroup(self, id):
        pg = self.portal.portal_groups
        pg.addGroup(id, '', (), ())
        return pg.getGroupById(id)


if __name__ == '__main__':
    framework()
else:
    # While framework.py provides its own test_suite()
    # method the testrunner utility does not.
    from unittest import TestSuite, makeSuite
    def test_suite():
        suite = TestSuite()
        suite.addTest(makeSuite(TestPloneCollabSpaceRolesReg))
        suite.addTest(makeSuite(TestPloneCollabSpaceUserAssignment))
        return suite
